@@ -62,7 +62,7 @@ A couple of RdfQuerys::
 And a web application::
 
     from oort.sitebase import *
-    from myapp import rdfqueries
+    from myapp import queries
     from myapp.ns import SITE
 
     class ExampleViewer(ResourceViewer):
@@ -76,12 +76,12 @@ And a web application::
             outputMethod = 'xhtml'
             outputEncoding  = 'iso-8859-1'
             templateBase = "view/mainweb"
-            globalQueries = {'languages': rdfqueries.sitelabels }
+            globalQueries = {'languages': queries.sitelabels }
             aspects = [
                     Aspect(SITE.SiteNode, "sitenode.xhtml",
-                            {'node': rdfqueries.SiteNode}) ,
+                            {'node': queries.SiteNode}) ,
                     Aspect(FOAF.Person, "person.xhtml",
-                            {'person': rdfqueries.Person}) ,
+                            {'person': queries.Person}) ,
                     Aspect(RDFS.Resource, "not_found.xhtml")
                 ]
 
@@ -89,7 +89,7 @@ And a web application::
             name = "json"
             contentType = 'application/x-javascript'
             aspects = [
-                    JsonAspect(SITE.SiteNode, {'node': rdfqueries.SiteNode})
+                    JsonAspect(SITE.SiteNode, {'node': queries.SiteNode})
                 ]
 
 But wait, there's more..
@@ -135,4 +135,5 @@ License: BSD-style <http://opensource.org/licenses/bsd-license>
 
 __docformat__ = 'reStructuredText en'
 __author__ = "Niklas Lindström"
+__version__ = "0.3.1"
 
