@@ -2,7 +2,8 @@
 # TODO: use Buffet-style templating instead (and provide way to serialize RdfQuery:s)
 #=======================================================================
 import os.path
-from rdflib import RDF, RDFS, Graph
+from rdflib import RDF, RDFS, ConjunctiveGraph
+from genshi.output import DocType
 from genshi.template import TemplateLoader
 from oort.util import templating
 from oort.util.code import contract, autosuper
@@ -35,7 +36,7 @@ class Display(DisplayBase):
         self.typeAspects = {}
         self.variantAspects = {}
         for aspect in self.aspects:
-            aspect.initialize(self.templateBase, self.globalQueries)
+            aspect.post_init_setup(self.templateBase, self.globalQueries)
             if aspect.forVariant:
                 variant = self.variantAspects.setdefault(aspect.forVariant, {})
                 typeDict = variant
@@ -97,7 +98,7 @@ class SubTypeAwareDisplay(Display):
                     for subSub in list_with_sub_types(subType):
                         yield subSub
 
-        sparseGraph = Graph()
+        sparseGraph = ConjunctiveGraph()
         for handledType in typeAspects:
             for anySub in list_with_sub_types(handledType):
                 for resource in graph.subjects(RDF.type, anySub):
@@ -127,7 +128,7 @@ class AspectBase:
         self.forVariant = forVariant
 
     @contract.state_change
-    def initialize(self, templateBase, globalQueries):
+    def post_init_setup(self, templateBase, globalQueries):
         self.templateBase = templateBase
         if globalQueries:
             queries = globalQueries.copy()
@@ -141,19 +142,24 @@ class AspectBase:
             for name, query in self.queries.items():
                 yield name, query(graph, lang, resource)
 
-    # TODO: redesign contract to set encoding and output(method) on call to Aspect#initialize?
+    # TODO: redesign contract to set encoding and output(method) on call to Aspect#post_init_setup?
     @contract.template_method
     def make_result_generator(self, graph, resource, lang, data=None):
-        """
-        Returns a generator that takes the arguments 'encoding' and 'output'.
-        """
+        """Returns a generator that takes the arguments 'encoding' and
+        'output'."""
         raise NotImplementedError
 
 
 class Aspect(AspectBase):
 
-    def initialize(self, base, globalQueries):
-        self.__super.initialize(base, globalQueries)
+    doctypes = dict(
+            (key.lower().replace('_', '-'), item)
+            for key, item in DocType.__dict__.items()
+            if key.isupper() and isinstance(item, tuple)
+        )
+
+    def post_init_setup(self, base, globalQueries):
+        self.__super.post_init_setup(base, globalQueries)
         loader = TemplateLoader(['.'], auto_reload=False)
         self.template = loader.load(os.path.join(base, self.templateName))
 
@@ -165,7 +171,10 @@ class Aspect(AspectBase):
         # take encoding. Find the simplest way to get around that (without too
         # much duplicatiom of render innards..).. Or just remove this todo?
         def generator(format, encoding):
-            yield tplt.generate(**allData).render(format, encoding=encoding)
+            doctype = self.doctypes.get(format)
+            format = format.split('-')[0]
+            yield tplt.generate(**allData).render(
+                    format, doctype=doctype, encoding=encoding)
         return generator
 
 
@@ -175,8 +184,8 @@ class TpltAspect(AspectBase):
 
     defaultEngine = "genshi"
 
-    def initialize(self, base, globalQueries):
-        self.__super.initialize(None, globalQueries)
+    def post_init_setup(self, base, globalQueries):
+        self.__super.post_init_setup(None, globalQueries)
         self.engine, self.path = self.engineManager.get_engine_and_path(
                 base+'.'+self.templateName, self.defaultEngine)
         template = self.engine.load_template(self.path)
@@ -203,7 +212,7 @@ class RdfAspect(AspectBase):
     def make_result_generator(self, graph, resource, lang, data=None):
         qData = dict( self.generate_query_items(graph, resource, lang) )
         def generator(format, encoding):
-            lgraph = Graph()
+            lgraph = ConjunctiveGraph()
             for key, result in qData.items():
                 lgraph += result.to_graph()
             yield lgraph.serialize(format='pretty-xml')
