@@ -1,6 +1,5 @@
 #=======================================================================
-import rdflib
-from rdflib import RDF, Namespace, Graph, BNode, Literal
+from rdflib import RDF, Namespace, ConjunctiveGraph, BNode, Literal
 try: import simplejson
 except ImportError: simplejson = None
 from oort.util.code import contract
@@ -27,28 +26,28 @@ def run_queries(queries, graph, subject, lang):
 
 
 class Selector(object):
-    __slots__ = ('predicate', 'namespace', 'subQuery', 'filters',
-                 'name', 'queryClass')
+    __slots__ = ('predicate', '_namespace', 'subQuery', 'filters',
+                 '_name', '_queryClass')
 
-    def __init__(self, base, subQuery=None):
-        if isinstance(base, Namespace):
-            self.namespace = base
+    def __init__(self, predBase, subQuery=None):
+        if isinstance(predBase, Namespace):
+            self._namespace = predBase
             self.predicate = None
         else:
-            self.namespace = None
-            self.predicate = base
+            self._namespace = None
+            self.predicate = predBase
         self.subQuery = subQuery
         self.filters = []
 
     @contract.state_change
     def hook_into_rdf_query(self, name, queryClass):
-        self.name = name
-        self.queryClass = queryClass
-        if not self.predicate and self.namespace:
-            self.predicate = self.namespace[name]
+        self._name = name
+        self._queryClass = queryClass
+        if not self.predicate and self._namespace:
+            self.predicate = self._namespace[name]
 
     def __get__(self, parentQuery, _parentQueryClass=None):
-        prep = parentQuery._preparedSelects[self.name]
+        prep = parentQuery._preparedSelects[self._name]
         if not prep.hasRun:
             result = self.retreive_result(parentQuery, prep.selectArgs)
             for fltr in self.filters:
@@ -80,7 +79,7 @@ class Selector(object):
         else:
             # FIXME: using THIS_QUERY may currently cause infinite loops.
             if subQuery is THIS_QUERY:
-                subQuery = self.queryClass
+                subQuery = self._queryClass
 
             if returnList:
                 return [subQuery(graph, lang, uri) for uri in rawresults]
@@ -88,7 +87,7 @@ class Selector(object):
                 return subQuery(graph, lang, rawresults)
 
     @contract.template_method
-    def select(self, graph, lang, subject, predicate):
+    def select(self, graph, lang, subject):
         raise NotImplementedError
         return None or []
 
@@ -104,12 +103,28 @@ class Selector(object):
         self.filters.append(fltr)
         return self
 
+    # TODO: Test! And consider if it's worth keeping.. At least make results 
+    # behave as selectors (so you can send them to other RdfQuery:s etc)
+    #def partition(self, useAttr, value):
+    #    """Example:
+    #        >>> class Typed(RdfQuery): type = one(RDF)
+    #        >>> class Ontology(RdfQuery):
+    #        >>>     members = each_where_self_is(RDFS.isDefinedBy) >> Typed
+    #        >>>     classes = members.partition('type', RDFS.Class)
+    #        >>>     properties = members.partition('type', RDF.Property)
+    #    """
+    #    selector = self
+    #    class Partitioner(object):
+    #        def __get__(self, parent, _parentClass=None):
+    #            items = selector.__get__(parent)
+    #            return [r for r in items if getattr(r, useAttr) == value]
+    #    return Partitioner()
 
-class PreparedSelect:
-    __slots__ = ('graph', 'subject', 'lang',
-                 'result', 'hasRun')
-    def __init__(self, graph, lang, subject, predicate):
-        self.selectArgs = graph, lang, subject, predicate
+
+class PreparedSelect(object):
+    __slots__ = ('selectArgs', 'result', 'hasRun')
+    def __init__(self, graph, lang, subject):
+        self.selectArgs = (graph, lang, subject)
         self.result = None
         self.hasRun = False # TODO: make configurable?
 
@@ -148,17 +163,27 @@ class RdfQuery(object):
         self._graph = graph
         self._subject = subject
         self._lang = lang
-        prepareds = self._preparedSelects = {}
+        self._preparedSelects = prepareds = {}
         for name, selector in self._selectors.items():
             if not subject: # FIXME: happens when subject is a bnode?
                 setattr(self, name, None)
                 continue
-            prep = PreparedSelect(graph, lang, subject, selector.predicate)
+            prep = PreparedSelect(graph, lang, subject)
             prepareds[name] = prep
 
     def __str__(self):
         return str(self._subject)
 
+    def __eq__(self, other):
+        if isinstance(other, RdfQuery):
+            return self._subject == other._subject
+        else:
+            return self._subject == other
+
+    @property
+    def uri(self):
+        return self._subject
+
     def get_selected_value(self, name):
         return self._preparedSelects[name].result
 
@@ -166,7 +191,7 @@ class RdfQuery(object):
         subject = self._subject or BNode() # FIXME: is this ok?
         if not subject: return # FIXME, see fixme in __init__
 
-        lgraph = lgraph or Graph()
+        lgraph = lgraph or ConjunctiveGraph()
 
         for t in self._graph.objects(subject, RDF.type):
             lgraph.add((subject, RDF.type, t))
@@ -188,13 +213,14 @@ class RdfQuery(object):
     def to_dict(self, keepSubject=False):
         d = {}
         if keepSubject:
+            # TODO: sync with new property 'uri'
             subjectKey = isinstance(keepSubject, str) and keepSubject or 'resource'
             subj = self._subject
             if subj and not isinstance(subj, BNode):
                 d[subjectKey] = self._subject
 
         for selector in self._selectors.values():
-            name = selector.name
+            name = selector._name
             value = selector.__get__(self)
             if not value:
                 continue
@@ -257,7 +283,7 @@ class Sorter(object):
 # TODO: totally untested!
 #def type_switch(typeSelectors, default):
 #    rdfType = graph.value(resource, RDF.type, None, any=True)
-#    def select(graph, resource, lang):
+#    def select(graph, lang, resource):
 #        return typeSelectors.get(rdfType, default)
 #    return select
 
@@ -284,13 +310,30 @@ class EachSelector(Selector):
 
 
 class one(UnarySelector):
-    def select(self, graph, lang, subject, predicate):
-        return graph.value(subject, predicate, None, any=True)
+    def select(self, graph, lang, subject):
+        return graph.value(subject, self.predicate, None, any=True)
 
 
 class each(EachSelector):
-    def select(self, graph, lang, subject, predicate):
-        return list(graph.objects(subject, predicate))
+    def select(self, graph, lang, subject):
+        return list(graph.objects(subject, self.predicate))
+
+
+class one_where_self_is(Selector):
+    def select(self, graph, lang, subject):
+        return graph.value(None, self.predicate, subject, any=True)
+
+    def back_to_graph(self, graph, subject, value):
+        back_from_value(graph, value._subject, self.predicate, subject)
+
+
+class each_where_self_is(Selector):
+    def select(self, graph, lang, subject):
+        return list(graph.subjects(self.predicate, subject))
+
+    def back_to_graph(self, graph, subject, values):
+        for value in values:
+            back_from_value(graph, value._subject, self.predicate, subject)
 
 
 class collection(Selector):
@@ -298,12 +341,15 @@ class collection(Selector):
         Selector.__init__(self, base, subQuery)
         self.multiple = multiple
 
-    def select(self, graph, lang, subject, predicate):
+    def select(self, graph, lang, subject):
         if self.multiple:
-            allItems = [graph.items(res) for res in graph.objects(subject, predicate)]
+            allItems = [graph.items(res)
+                        for res in graph.objects(subject, self.predicate)]
             return list(chain(*allItems))
         else:
-            return list(graph.items(graph.value(subject, predicate, None, any=True)))
+            return list(graph.items(
+                    graph.value(subject, self.predicate, None, any=True)
+                ))
 
     def back_to_graph(self, graph, subject, values):
         if not values:
@@ -320,9 +366,9 @@ class collection(Selector):
 
 
 class localized(UnarySelector):
-    def select(self, graph, lang, subject, predicate):
+    def select(self, graph, lang, subject):
         first = None
-        for value in graph.objects(subject, predicate):
+        for value in graph.objects(subject, self.predicate):
             if not first: first = value
             if getattr(value, 'language', None) == lang:
                 return value
@@ -338,14 +384,15 @@ class localized_xml(UnarySelector):
 
     Important! This is currently tied to the Genshi Templating System, and may 
     not work as expected in all cases."""
-    def select(self, graph, lang, subject, predicate):
-        return language_filtered_xml(graph.objects(subject, predicate), lang)
+    def select(self, graph, lang, subject):
+        return language_filtered_xml(
+                graph.objects(subject, self.predicate), lang)
 
 
 class i18n_dict(Selector):
-    def select(self, graph, lang, subject, predicate):
+    def select(self, graph, lang, subject):
         valueDict = {}
-        for value in graph.objects(subject, predicate):
+        for value in graph.objects(subject, self.predicate):
             valueDict[value.language] = value
         return valueDict
 
@@ -355,8 +402,8 @@ class i18n_dict(Selector):
 
 
 class each_localized(EachSelector):
-    def select(self, graph, lang, subject, predicate):
-        return [ value for value in graph.objects(subject, predicate)
+    def select(self, graph, lang, subject):
+        return [ value for value in graph.objects(subject, self.predicate)
                  if value.language == lang ]
 
 
@@ -393,7 +440,7 @@ class selector(Selector):
 #=======================================
 
 def chain(*iters):
-    for iter in iters:
-        for i in iter: yield i
+    for iterator in iters:
+        for i in iterator: yield i
 
 
