@@ -1,5 +1,5 @@
 #=======================================================================
-from rdflib import Graph, Namespace, URIRef, RDF, RDFS
+from rdflib import ConjunctiveGraph, Namespace, URIRef, RDF, RDFS
 from oort.display import SubTypeAwareDisplay
 #=======================================================================
 
@@ -17,7 +17,7 @@ class TestSubTypeAwareDisplay:
     def test_create_match_graph(self):
         # TODO: verify test accuracy; then remake into test generator (see nose)
 
-        graph = Graph()
+        graph = ConjunctiveGraph()
 
         def classAndSubClass(C1, C2):
             graph.add( (C1, RDF.type, RDFS.Class) )
