@@ -1,4 +1,4 @@
-from rdflib import *
+from rdflib import ConjunctiveGraph, URIRef
 from oort.rdfview import *
 
 
@@ -16,23 +16,10 @@ class Item(Part):
     titleLang = i18n_dict(T['title'])
     labels = each_localized(T.label)
 
-class RichItem(Item):
-    xmlData = localized_xml(T)
 
-class CustomItem(Item):
-    @selector
-    def randomRelation(self, graph, lang, subject, predicate):
-        from random import randint
-        assert isinstance(self, CustomItem)
-        itemUris = [uri for uri in graph.subjects(RDF.type, T.Item)
-                        if uri != subject]
-        return Part(graph, lang, itemUris[randint(0, len(itemUris)-1)])
-
-
-class FilteredItem(RdfQuery):
-    sortedKeywords = each(T.keyword) | Sorter()
-    sortedKeywordsReversed = each(T.keyword) | Sorter(reverse=True)
-    someKeywords = each(T.keyword) | Filter(lambda v: v in ('q', 'r', 'y'))
+def assert_contains(graph, query):
+    for spo in query.to_graph():
+        assert spo in graph
 
 
 #=======================================
@@ -40,10 +27,10 @@ class FilteredItem(RdfQuery):
 
 import os
 TEST_DATA = os.path.join(os.path.dirname(__file__), 'testdata.n3')
-graph = rdflib.Graph()
+graph = ConjunctiveGraph()
 graph.load(open(TEST_DATA), format='n3')
 
-itemX = URIRef('urn:test:item:x')
+itemX = URIRef('tag:oort.to,2006:test:item:x')
 en, sv = 'en', 'sv'
 
 def test_one():
@@ -65,6 +52,9 @@ def test_localized():
     for l, v in [(en, u'Example Item'), (sv, u'Exempelsak')]:
         yield assert_equals, Item(graph, l, itemX).title, v
 
+class RichItem(Item):
+    xmlData = localized_xml(T)
+
 def test_localized_xml():
     for l, v in [(en, u'XML Data'), (sv, u'XML-data')]:
         treeData = list(RichItem(graph, l, itemX).xmlData)
@@ -84,6 +74,25 @@ def test_each_localized():
     assert set(Item(graph, sv, itemX).labels) == set([u'Sv', u'sV'])
 
 
+class Creation(RdfQuery):
+    createdBy = one_where_self_is(T.creation) >> Part
+
+def test_one_where_self_is():
+    creation = Creation(graph, en, itemX)
+    assert creation.createdBy.name == "Creator"
+    assert_contains(graph, creation)
+
+
+class Owner(RdfQuery):
+    owns = each_where_self_is(T.owner) >> Part
+
+def test_each_where_self_is():
+    owner = Owner(graph, en, itemX)
+    owned = [part.name for part in owner.owns]
+    assert set(owned) == set(["Part A", "Part B"])
+    assert_contains(graph, owner)
+
+
 def test_to_json():
     json = Item(graph, en, itemX).to_json()
     d = eval(json)
@@ -95,10 +104,24 @@ def test_to_graph():
     # TODO: inspect!
 
 
+class CustomItem(Item):
+    @selector
+    def randomRelation(self, graph, lang, subject):
+        from random import randint
+        assert isinstance(self, CustomItem)
+        itemUris = [uri for uri in graph.subjects(RDF.type, T.Item)
+                        if uri != subject]
+        return Part(graph, lang, itemUris[randint(0, len(itemUris)-1)])
+
 def test_selector_decorator():
     assert CustomItem(graph, en, itemX).randomRelation.name.startswith("Related ")
 
 
+class FilteredItem(RdfQuery):
+    sortedKeywords = each(T.keyword) | Sorter()
+    sortedKeywordsReversed = each(T.keyword) | Sorter(reverse=True)
+    someKeywords = each(T.keyword) | Filter(lambda v: v in ('q', 'r', 'y'))
+
 def test_filter():
     item = FilteredItem(graph, en, itemX)
 
