@@ -1,5 +1,5 @@
 #=======================================================================
-from rdflib import Graph
+from rdflib import ConjunctiveGraph
 from oort.sitebase import MultiBaseResourceViewer
 #=======================================================================
 
@@ -19,11 +19,11 @@ def test_MultiBaseResourceViewer():
         }
         defaultResource = 'http://example.org/default/resource'
 
-    viewer = TestViewer(Graph())
+    viewer = TestViewer(ConjunctiveGraph())
     def test_path(path, expected, samePath=True):
         resource = viewer.resource_from(path.split('/'))
         assert resource == expected
-        path2, _success = viewer.resource_to_lpath(resource)
+        path2, _success = viewer.resource_to_app_path(resource)
         assert (path == path2) is samePath
 
     test_path("ex/path/to/resource", "http://example.org/resources/path/to/resource")
