@@ -1,6 +1,6 @@
 from rdflib import URIRef, RDF, RDFS
 from oort.rdfview import RdfQuery, one, localized, i18n_dict
-from oort.util.code import Slotted
+from oort.util.code import SlotStruct
 
 class HasLabel(RdfQuery):
     label = localized(RDFS.RDFSNS)
@@ -8,7 +8,7 @@ class HasLabel(RdfQuery):
 def make_label_query(uriBase, *uriTails):
     def labels(graph, lang, resource):
         labelBase = uriBase + "%s"
-        class Labels(Slotted):
+        class Labels(SlotStruct):
             __slots__ = uriTails
         return Labels(
                 *[HasLabel(graph, lang, URIRef(labelBase % tail)).label
